@@ -13,12 +13,11 @@ func (m PagerModeMark) drawFooter(_ string, _ string) {
 
 	pos := 0
 	for _, token := range "Press any key to label your mark: " {
-		p.screen.SetCell(pos, height-1, twin.NewCell(token, twin.StyleDefault))
-		pos++
+		pos += p.screen.SetCell(pos, height-1, twin.NewStyledRune(token, twin.StyleDefault))
 	}
 
 	// Add a cursor
-	p.screen.SetCell(pos, height-1, twin.NewCell(' ', twin.StyleDefault.WithAttr(twin.AttrReverse)))
+	p.screen.SetCell(pos, height-1, twin.NewStyledRune(' ', twin.StyleDefault.WithAttr(twin.AttrReverse)))
 }
 
 func (m PagerModeMark) onKey(key twin.KeyCode) {
