@@ -41,11 +41,12 @@ func printProblemsHeader() {
 	fmt.Fprintln(os.Stderr, "Please post the following report at <https://github.com/walles/moar/issues>,")
 	fmt.Fprintln(os.Stderr, "or e-mail it to johan.walles@gmail.com.")
 	fmt.Fprintln(os.Stderr)
-	fmt.Fprintln(os.Stderr, "Version:", getVersion())
-	fmt.Fprintln(os.Stderr, "LANG   :", os.Getenv("LANG"))
-	fmt.Fprintln(os.Stderr, "TERM   :", os.Getenv("TERM"))
-	fmt.Fprintln(os.Stderr, "MOAR   :", os.Getenv("MOAR"))
-	fmt.Fprintln(os.Stderr, "EDITOR :", os.Getenv("EDITOR"))
+	fmt.Fprintln(os.Stderr, "Version     :", getVersion())
+	fmt.Fprintln(os.Stderr, "LANG        :", os.Getenv("LANG"))
+	fmt.Fprintln(os.Stderr, "TERM        :", os.Getenv("TERM"))
+	fmt.Fprintln(os.Stderr, "MOAR        :", os.Getenv("MOAR"))
+	fmt.Fprintln(os.Stderr, "EDITOR      :", os.Getenv("EDITOR"))
+	fmt.Fprintln(os.Stderr, "TERM_PROGRAM:", os.Getenv("TERM_PROGRAM"))
 	fmt.Fprintln(os.Stderr)
 	fmt.Fprintln(os.Stderr, "GOOS    :", runtime.GOOS)
 	fmt.Fprintln(os.Stderr, "GOARCH  :", runtime.GOARCH)
@@ -356,7 +357,7 @@ func pagerFromArgs(
 	noLineNumbers := flagSet.Bool("no-linenumbers", noLineNumbersDefault(), "Hide line numbers on startup, press left arrow key to show")
 	noStatusBar := flagSet.Bool("no-statusbar", false, "Hide the status bar, toggle with '='")
 	reFormat := flagSet.Bool("reformat", false, "Reformat some input files (JSON)")
-	flagSet.Bool("no-reformat", true, "No effect, kept for compatibility. See --reforamat")
+	flagSet.Bool("no-reformat", true, "No effect, kept for compatibility. See --reformat")
 	quitIfOneScreen := flagSet.Bool("quit-if-one-screen", false, "Don't page if contents fits on one screen")
 	noClearOnExit := flagSet.Bool("no-clear-on-exit", false, "Retain screen contents when exiting moar")
 	statusBarStyle := flagSetFunc(flagSet, "statusbar", m.STATUSBAR_STYLE_INVERSE,
@@ -543,7 +544,7 @@ func pagerFromArgs(
 				}
 
 			default:
-				log.Debug("Expected terminal background color event but got ", ev, " after ", time.Since(t0), " putting back and giving up")
+				log.Debugf("Expected terminal background color event but got %#v after %s, putting back and giving up", ev, time.Since(t0))
 				screen.Events() <- event
 			}
 
